@@ -17,17 +17,17 @@ import click
 import git
 import sys
 from github import Github
+from commands import auth
+from commands import allrepo
+from commands import selectrepo
+from commands import webhook
 
 
-import auth
-import selectrepo
-import allrepo
-import webhook
-
 
 
 def main():
     buildpan()
+
 @click.group(help="CLI tool to manage full development cycle of projects")
 def buildpan():
     pass
